@@ -43,13 +43,94 @@ This module contains a document language model for VHDL.
 # load dependencies
 from enum               import Enum
 from pathlib            import Path
-from typing             import Any, List, Tuple
+from typing             import List, Tuple, Union
 
 from pydecor.decorators import export
 
 __all__ = []
 #__api__ = __all__ # FIXME: disabled due to a bug in pydecors export decorator
 
+LibraryOrSymbol =       Union['Library',       'LibrarySymbol']
+EntityOrSymbol =        Union['Entity',        'EntitySymbol']
+ArchitectureOrSymbol =  Union['Architecture',  'ArchitectureSymbol']
+PackageOrSymbol =       Union['Package',       'PackageSymbol']
+ConfigurationOrSymbol = Union['Configuration', 'ConfigurationSymbol']
+ContextOrSymbol =       Union['Context',       'ContextSymbol']
+
+SubTypeOrSymbol =       Union['SubType',       'SubTypeSymbol']
+
+ConstantOrSymbol =      Union['Constant',      'ConstantSymbol']
+VariableOrSymbol =      Union['Variable',      'VariableSymbol']
+SignalOrSymbol =        Union['Signal',        'SignalSymbol']
+
+Constraint = Union[
+	'RangeExpression',
+	'RangeAttribute',
+	'RangeSubtype',
+]
+
+Expression = Union[
+	'BaseExpression',
+	'QualifiedExpression',
+	'FunctionCall',
+	'TypeConversion',
+	ConstantOrSymbol,
+	VariableOrSymbol,
+	SignalOrSymbol,
+	'Literal',
+]
+
+
+@export
+class Direction(Enum):
+	"""
+	A ``Direction`` is an enumeration and represents a direction in a range
+	(``to`` or ``downto``).
+	"""
+	To =      0
+	DownTo =  1
+
+	def __str__(self):
+		return ("to", "downto")[self.value]       # TODO: check performance
+
+
+@export
+class Mode(Enum):
+	"""
+	A ``Mode`` is an enumeration. It represents the direction of data exchange
+	(``in``, ``out``, ...) for objects in generic, port or parameter lists.
+
+	In case no *mode* is define, ``Default`` is used, so the *mode* is inferred
+	from context.
+	"""
+	Default = 0
+	In =      1
+	Out =     2
+	InOut =   3
+	Buffer =  4
+	Linkage = 5
+
+	def __str__(self):
+			return ("", "in", "out", "inout", "buffer", "linkage")[self.value]       # TODO: check performance
+
+
+@export
+class Class(Enum):
+	"""
+	A ``Class`` is an enumeration. It represents an object's class (``constant``,
+	``signal``, ...).
+
+	In case no *object class* is define, ``Default`` is used, so the *object class*
+	is inferred from context.
+	"""
+	Default =    0
+	Constant =   1
+	Variable =   2
+	Signal =     3
+	File =       4
+	Type =       5
+	Subprogram = 6
+
 
 @export
 class ModelEntity:
@@ -111,6 +192,213 @@ class LabeledEntity:
 		return self._label
 
 
+@export
+class Symbol(ModelEntity):
+	_symbolName: str
+
+	def __init__(self, symbolName: str):
+		super().__init__()
+		self._symbolName = symbolName
+
+	@property
+	def SymbolName(self) -> str:
+		return self._symbolName
+
+	def __str__(self) -> str:
+		return self._symbolName
+
+
+@export
+class LibrarySymbol(Symbol):
+	_library: 'Library'
+
+	def __init__(self):
+		super().__init__()
+		self._library = None
+
+	@property
+	def Library(self) -> 'Library':
+		return self._library
+
+	def ResolvesTo(self, library: 'Library'):
+		self._library = library
+
+
+@export
+class EntitySymbol(Symbol):
+	_entity: 'Entity'
+
+	def __init__(self, entityName: str):
+		super().__init__(symbolName=entityName)
+
+		self._entity = None
+
+	@property
+	def Package(self) -> 'Entity':
+		return self._entity
+
+
+@export
+class ArchitectureSymbol(Symbol):
+	_architecture: 'Architecture'
+
+	def __init__(self):
+		super().__init__()
+		self._architecture = None
+
+	@property
+	def Architecture(self) -> 'Architecture':
+		return self._architecture
+
+
+@export
+class ConfigurationSymbol(Symbol):
+	_configuration: 'Configuration'
+
+	def __init__(self):
+		super().__init__()
+		self._configuration = None
+
+	@property
+	def Configuration(self) -> 'Configuration':
+		return self._configuration
+
+
+@export
+class PackageSymbol(Symbol):
+	_package: 'Package'
+
+	def __init__(self):
+		super().__init__()
+		self._package = None
+
+	@property
+	def Package(self) -> 'Package':
+		return self._package
+
+
+@export
+class ContextSymbol(Symbol):
+	_context: 'Context'
+
+	def __init__(self):
+		super().__init__()
+		self._context = None
+
+	@property
+	def Context(self) -> 'Context':
+		return self._context
+
+
+@export
+class SubTypeSymbol(Symbol):
+	_subType:     'SubType'
+
+	@property
+	def SubType(self) -> 'SubType':
+		return self._subType
+
+
+@export
+class SimpleSubTypeSymbol(SubTypeSymbol):
+	def __init__(self, subTypeName: str):
+		super().__init__(symbolName = subTypeName)
+		self._subType = None
+
+
+@export
+class ConstrainedSubTypeSymbol(SubTypeSymbol):
+	_constraints: List[Constraint]
+
+	def __init__(self, subTypeName: str, constraints: List[Constraint] = None):
+		super().__init__(symbolName = subTypeName)
+		self._subType = None
+		self._constraints = constraints
+
+	@property
+	def Constraints(self) -> List[Constraint]:
+		return self._constraints
+
+
+@export
+class EnumerationLiteralSymbol(Symbol):
+	pass
+
+
+@export
+class ObjectSymbol(Symbol):
+	pass
+
+@export
+class SimpleObjectSymbol(Symbol):
+	_object: Union['Constant', 'Signal', 'Variable']
+
+	def __init__(self, objectName: str):
+		super().__init__(objectName)
+		self._object = None
+
+	@property
+	def Object(self) -> Union['Constant', 'Signal', 'Variable']:
+		return self._object
+
+	def __str__(self) -> str:
+		if self._object is not None:
+			return str(self._object)
+		return super().__str__()
+
+
+@export
+class ConstantSymbol(ObjectSymbol):
+	_constant: 'Constant'
+
+	def __init__(self):
+		super().__init__()
+		self._constant = None
+
+	@property
+	def Constant(self) -> 'Constant':
+		return self._constant
+
+
+@export
+class VariableSymbol(ObjectSymbol):
+	_variable: 'Variable'
+
+	def __init__(self):
+		super().__init__()
+		self._variable = None
+
+	@property
+	def Variable(self) -> 'Variable':
+		return self._variable
+
+
+@export
+class SignalSymbol(ObjectSymbol):
+	_signal: 'Signal'
+
+	def __init__(self):
+		super().__init__()
+		self._signal = None
+
+	@property
+	def Signal(self) -> 'Signal':
+		return self._signal
+
+
+@export
+class FileSymbol(ObjectSymbol):
+	_file: 'File'
+
+	def __init__(self):
+		super().__init__()
+		self._file = None
+
+	@property
+	def File(self) -> 'File':
+		return self._file
+
+
 @export
 class Design(ModelEntity):
 	"""
@@ -239,51 +527,6 @@ class Document(ModelEntity):
 		return self._packageBodies
 
 
-@export
-class Direction(Enum):
-	"""
-	A ``Direction`` is an enumeration and represents a direction in a range
-	(``to`` or ``downto``).
-	"""
-	To =      0
-	DownTo =  1
-
-
-@export
-class Mode(Enum):
-	"""
-	A ``Mode`` is an enumeration. It represents the direction of data exchange
-	(``in``, ``out``, ...) for objects in generic, port or parameter lists.
-
-	In case no *mode* is define, ``Default`` is used, so the *mode* is inferred
-	from context.
-	"""
-	Default = 0
-	In =      1
-	Out =     2
-	InOut =   3
-	Buffer =  4
-	Linkage = 5
-
-
-@export
-class Class(Enum):
-	"""
-	A ``Class`` is an enumeration. It represents an object's class (``constant``,
-	``signal``, ...).
-
-	In case no *object class* is define, ``Default`` is used, so the *object class*
-	is inferred from context.
-	"""
-	Default =    0
-	Constant =   1
-	Variable =   2
-	Signal =     3
-	File =       4
-	Type =       5
-	Subprogram = 6
-
-
 @export
 class BaseType(ModelEntity, NamedEntity):
 	"""``BaseType`` is the base class of all type entities in this model."""
@@ -342,15 +585,15 @@ class RangedScalarType(ScalarType):
 	A ``RangedScalarType`` is a base-class for all scalar types with a range.
 	"""
 
-	_leftBound:  'Expression'
-	_rightBound: 'Expression'
+	_leftBound: Expression
+	_rightBound: Expression
 
 	@property
-	def LeftBound(self) -> 'Expression':
+	def LeftBound(self) -> Expression:
 		return self._leftBound
 
 	@property
-	def RightBound(self) -> 'Expression':
+	def RightBound(self) -> Expression:
 		return self._rightBound
 
 
@@ -485,19 +728,20 @@ class RecordType(CompositeType):
 
 
 @export
-class Expression(ModelEntity):
+class BaseExpression(ModelEntity):
 	"""
-	A ``Expression`` is a base-class for all expressions.
+	A ``BaseExpression`` is a base-class for all expressions.
 	"""
 
 
 @export
-class Literal(Expression):
+class Literal(BaseExpression):
 	"""
 	A ``Literal`` is a base-class for all literals.
 	"""
 # TODO: add a reference to a basetype ?
 
+
 @export
 class EnumerationLiteral(Literal):
 	_value: str
@@ -509,6 +753,9 @@ class EnumerationLiteral(Literal):
 	def Value(self) -> str:
 		return self._value
 
+	def __str__(self) -> str:
+		return self._value
+
 
 @export
 class NumericLiteral(Literal):
@@ -522,70 +769,124 @@ class IntegerLiteral(NumericLiteral):
 	_value: int
 
 	def __init__(self, value: int):
+		super().__init__()
 		self._value = value
 
 	@property
 	def Value(self) -> int:
 		return self._value
 
+	def __str__(self) -> str:
+		return str(self._value)
+
 
 @export
 class FloatingPointLiteral(NumericLiteral):
 	_value: float
 
 	def __init__(self, value: float):
+		super().__init__()
 		self._value = value
 
 	@property
 	def Value(self) -> float:
 		return self._value
 
+	def __str__(self) -> str:
+		return str(self._value)
+
+
 @export
 class PhysicalLiteral(NumericLiteral):
 	pass
 
+
 @export
 class CharacterLiteral(Literal):
-	pass
+	_value: str
+
+	def __init__(self, value: str):
+		super().__init__()
+		self._value = value
+
+	@property
+	def Value(self) -> str:
+		return self._value
+
+	def __str__(self) -> str:
+		return str(self._value)
+
 
 @export
 class StringLiteral(Literal):
-	pass
+	_value: str
+
+	def __init__(self, value: str):
+		super().__init__()
+		self._value = value
+
+	@property
+	def Value(self) -> str:
+		return self._value
+
+	def __str__(self) -> str:
+		return "\"" + self._value + "\""
+
 
 @export
 class BitStringLiteral(Literal):
-	pass
+	_value: str
+
+	def __init__(self, value: str):
+		super().__init__()
+		self._value = value
+
+	@property
+	def Value(self) -> str:
+		return self._value
+
+	def __str__(self) -> str:
+		return "\"" + self._value + "\""
 
 
 @export
-class UnaryExpression(Expression):
+class UnaryExpression(BaseExpression):
 	"""
 	A ``UnaryExpression`` is a base-class for all unary expressions.
 	"""
+
+	_FORMAT: Tuple[str, str]
 	_operand:  Expression
 
 	def __init__(self):
-		pass
+		super().__init__()
 
 	@property
 	def Operand(self):
 		return self._operand
 
+	def __str__(self) -> str:
+		return "{leftOperator}{operand!s}{rightOperator}".format(
+			leftOperator=self._FORMAT[0],
+			operand=self._operand,
+			rightOperator=self._FORMAT[1],
+		)
+
 @export
 class InverseExpression(UnaryExpression):
-	pass
+	_FORMAT = ("-", "")
 
 @export
 class IdentityExpression(UnaryExpression):
-	pass
+	_FORMAT = ("+", "")
 
 @export
 class NegationExpression(UnaryExpression):
-	pass
+	_FORMAT = ("not ", "")
 
 @export
 class AbsoluteExpression(UnaryExpression):
-	pass
+	_FORMAT = ("abs ", "")
 
 @export
 class TypeConversion(UnaryExpression):
@@ -596,20 +897,22 @@ class FunctionCall(UnaryExpression):
 	pass
 
 @export
-class QualifiedExpression(UnaryExpression):
-	pass
+class ParenthesisExpression(UnaryExpression):
+	_FORMAT = ("(", ")")
+
 
 @export
-class BinaryExpression(Expression):
+class BinaryExpression(BaseExpression):
 	"""
 	A ``BinaryExpression`` is a base-class for all binary expressions.
 	"""
 
+	_FORMAT: Tuple[str, str, str]
 	_leftOperand:  Expression
 	_rightOperand: Expression
 
 	def __init__(self):
-		pass
+		super().__init__()
 
 	@property
 	def LeftOperand(self):
@@ -619,6 +922,19 @@ class BinaryExpression(Expression):
 	def RightOperand(self):
 		return self._rightOperand
 
+	def __str__(self) -> str:
+		return "{leftOperator}{leftOperand!s}{middleOperator}{rightOperand!s}{rightOperator}".format(
+			leftOperator=self._FORMAT[0],
+			leftOperand=self._leftOperand,
+			middleOperator=self._FORMAT[1],
+			rightOperand=self._rightOperand,
+			rightOperator=self._FORMAT[2],
+		)
+
+
+@export
+class QualifiedExpression(BinaryExpression):
+	pass
 
 @export
 class	AddingExpression(BinaryExpression):
@@ -628,15 +944,15 @@ class	AddingExpression(BinaryExpression):
 
 @export
 class	AdditionExpression(AddingExpression):
-	pass
+	_FORMAT = ("", " + ", "")
 
 @export
 class	SubtractionExpression(AddingExpression):
-	pass
+	_FORMAT = ("", " - ", "")
 
 @export
 class	ConcatenationExpression(AddingExpression):
-	pass
+	_FORMAT = ("", " & ", "")
 
 @export
 class	MultiplyingExpression(BinaryExpression):
@@ -646,23 +962,23 @@ class	MultiplyingExpression(BinaryExpression):
 
 @export
 class	MultiplyExpression(MultiplyingExpression):
-	pass
+	_FORMAT = ("", " * ", "")
 
 @export
 class	DivisionExpression(MultiplyingExpression):
-	pass
+	_FORMAT = ("", " / ", "")
 
 @export
 class	RemainderExpression(MultiplyingExpression):
-	pass
+	_FORMAT = ("", " rem ", "")
 
 @export
 class	ModuloExpression(MultiplyingExpression):
-	pass
+	_FORMAT = ("", " mod ", "")
 
 @export
 class	ExponentiationExpression(MultiplyingExpression):
-	pass
+	_FORMAT = ("", "**", "")
 
 @export
 class	LogicalExpression(BinaryExpression):
@@ -672,27 +988,27 @@ class	LogicalExpression(BinaryExpression):
 
 @export
 class AndExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " and ", "")
 
 @export
 class NandExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " nand ", "")
 
 @export
 class OrExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " or ", "")
 
 @export
 class NorExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " nor ", "")
 
 @export
 class XorExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " xor ", "")
 
 @export
 class	XnorExpression(LogicalExpression):
-	pass
+	_FORMAT = ("", " xnor ", "")
 
 @export
 class	RelationalExpression(BinaryExpression):
@@ -702,23 +1018,27 @@ class	RelationalExpression(BinaryExpression):
 
 @export
 class	EqualExpression(RelationalExpression):
-	pass
+	_FORMAT = ("", " = ", "")
 
 @export
 class	UnequalExpression(RelationalExpression):
-	pass
+	_FORMAT = ("", " /= ", "")
 
 @export
 class	GreaterThanExpression(RelationalExpression):
-	pass
+	_FORMAT = ("", " > ", "")
 
 @export
 class	GreaterEqualExpression(RelationalExpression):
-	pass
+	_FORMAT = ("", " >= ", "")
 
 @export
 class	LessThanExpression(RelationalExpression):
-	pass
+	_FORMAT = ("", " < ", "")
+
+@export
+class	LessEqualExpression(RelationalExpression):
+	_FORMAT = ("", " <= ", "")
 
 
 @export
@@ -741,40 +1061,41 @@ class RotateExpression(ShiftExpression):
 
 @export
 class	ShiftRightLogicExpression(ShiftLogicExpression):
-	pass
+	_FORMAT = ("", " srl ", "")
 
 @export
 class	ShiftLeftLogicExpression(ShiftLogicExpression):
-	pass
+	_FORMAT = ("", " sll ", "")
 
 @export
 class	ShiftRightArithmeticExpression(ShiftArithmeticExpression):
-	pass
+	_FORMAT = ("", " sra ", "")
 
 @export
 class	ShiftLeftArithmeticExpression(ShiftArithmeticExpression):
-	pass
+	_FORMAT = ("", " sla ", "")
 
 @export
 class	RotateRightExpression(RotateExpression):
-	pass
+	_FORMAT = ("", " ror ", "")
 
 @export
 class	RotateLeftExpression(RotateExpression):
-	pass
+	_FORMAT = ("", " rol ", "")
 
 @export
-class TernaryExpression(Expression):
+class TernaryExpression(BaseExpression):
 	"""
 	A ``TernaryExpression`` is a base-class for all ternary expressions.
 	"""
 
+	_FORMAT: Tuple[str, str, str, str]
 	_firstOperand:  Expression
 	_secondOperand: Expression
 	_thirdOperand:  Expression
 
 	def __init__(self):
-		pass
+		super().__init__()
 
 	@property
 	def FirstOperand(self):
@@ -788,26 +1109,170 @@ class TernaryExpression(Expression):
 	def ThirdOperand(self):
 		return self._thirdOperand
 
+	def __str__(self) -> str:
+		return "{beforeFirstOperator}{firstOperand!s}{beforeSecondOperator}{secondOperand!s}{beforeThirdOperator}{thirdOperand!s}{lastOperator}".format(
+			beforeFirstOperator=self._FORMAT[0],
+			firstOperand=self._firstOperand,
+			beforeSecondOperator=self._FORMAT[1],
+			secondOperand=self._secondOperand,
+			beforeThirdOperator=self._FORMAT[2],
+			thirdOperand=self._thirdOperand,
+			lastOperator=self._FORMAT[4],
+		)
+
 
 @export
-class Range:
-	_leftBound:  Any
-	_rightBound: Any
+class	WhenElseExpression(TernaryExpression):
+	_FORMAT = ("", " when ", " else ", "")
+
+
+@export
+class AggregateElement(ModelEntity):
+	"""
+	A ``AggregateElement`` is a base-class for all aggregate elements.
+	"""
+
+	_expression: Expression
+
+	@property
+	def Expression(self):
+		return self._expression
+
+
+@export
+class SimpleAggregateElement(AggregateElement):
+	def __str__(self) -> str:
+		return str(self._expression)
+
+
+@export
+class IndexedAggregateElement(AggregateElement):
+	_index: int
+
+	@property
+	def Index(self) -> int:
+		return self._index
+
+	def __str__(self) -> str:
+		return "{index!s} => {value!s}".format(
+			index=self._index,
+			value=self._expression,
+		)
+
+
+@export
+class RangedAggregateElement(AggregateElement):
+	_range: 'Range'
+
+	@property
+	def Range(self) -> 'Range':
+		return self._range
+
+	def __str__(self) -> str:
+		return "{range!s} => {value!s}".format(
+			range=self._range,
+			value=self._expression,
+		)
+
+
+@export
+class NamedAggregateElement(AggregateElement):
+	_name: EnumerationLiteralSymbol
+
+	@property
+	def Name(self) -> EnumerationLiteralSymbol:
+		return self._name
+
+	def __str__(self) -> str:
+		return "{name!s} => {value!s}".format(
+			name=self._name,
+			value=self._expression,
+		)
+
+
+@export
+class OthersAggregateElement(AggregateElement):
+	def __str__(self) -> str:
+		return "others => {value!s}".format(
+			value=self._expression,
+		)
+
+
+@export
+class Aggregate(BaseExpression):
+	_elements: List[AggregateElement]
+
+	@property
+	def Elements(self) -> List[AggregateElement]:
+		return self._elements
+
+	def __str__(self) -> str:
+		choices = [self.formatAggregateElement(element) for element in self._elements]
+		return "({choices})".format(
+			choices=", ".join(choices)
+		)
+
+
+@export
+class Range(ModelEntity):
+	_leftBound:  Expression
+	_rightBound: Expression
 	_direction:  Direction
 
-	def __init__(self):
-		pass
+	@property
+	def LeftBound(self) -> Expression:
+		return self._leftBound
+
+	@property
+	def RightBound(self) -> Expression:
+		return self._rightBound
+
+	@property
+	def Direction(self) -> Direction:
+		return self._direction
+
+	def __str__(self) -> str:
+		return "{leftBound!s} {direction!s} {rightBound!s}".format(
+			leftBound=self._leftBound,
+			direction=self._direction,
+			rightBound=self._rightBound,
+		)
+
+
+@export
+class BaseConstraint(ModelEntity):
+	pass
+
+
+@export
+class RangeExpression(BaseConstraint):
+	_range: Range
+
+	@property
+	def Range(self):
+		return self._range
+
+
+@export
+class RangeAttribute(BaseConstraint):
+	pass
+
+
+@export
+class RangeSubtype(BaseConstraint):
+	pass
+
 
 @export
 class Object(ModelEntity, NamedEntity):
-	_subType: SubType
+	_subType: SubTypeOrSymbol
 
 	def __init__(self, name: str):
 		super().__init__()
 		NamedEntity.__init__(self, name)
 
 	@property
-	def SubType(self) -> SubType:
+	def SubType(self) -> SubTypeOrSymbol:
 		return self._subType
 
 
@@ -1059,23 +1524,27 @@ class ParameterFileInterfaceItem(File, ParameterInterfaceItem):
 # 		self._mode =        None
 # 		self._class =       None
 
+@export
+class Reference(ModelEntity):
+	pass
+
 
 @export
-class LibraryReference(ModelEntity):
-	_library: Library
+class LibraryStatement(Reference):
+	_library:       Union[None, LibraryOrSymbol]
 
 	def __init__(self):
 		super().__init__()
 		self._library = None
 
 	@property
-	def Library(self) -> Library:
+	def Library(self) -> Union[None, LibraryOrSymbol]:
 		return self._library
 
 
 @export
-class PackageReference(ModelEntity):
-	_library: Library
+class UseStatement(Reference):
+	_library: Union[None, LibraryOrSymbol]
 	_package: 'Package'
 	_item:    str
 
@@ -1083,7 +1552,7 @@ class PackageReference(ModelEntity):
 		super().__init__()
 
 	@property
-	def Library(self) -> Library:
+	def Library(self) -> Union[None, LibraryOrSymbol]:
 		return self._library
 
 	@property
@@ -1096,15 +1565,15 @@ class PackageReference(ModelEntity):
 
 
 @export
-class ContextReference(ModelEntity):
-	_library: Library
+class ContextStatement(Reference):
+	_library: Union[None, LibraryOrSymbol]
 	_context: 'Context'
 
 	def __init__(self):
 		super().__init__()
 
 	@property
-	def Library(self) -> Library:
+	def Library(self) -> Union[None, LibraryOrSymbol]:
 		return self._library
 
 	@property
@@ -1127,8 +1596,8 @@ class MixinDesignUnitWithContext:
 	"""
 	A ``DesignUnitWithReferences`` is a base-class for all design units with contexts.
 	"""
-	_libraryReferences: List[Library]
-	_packageReferences: List[PackageReference]
+	_libraryReferences: List[LibraryStatement]
+	_packageReferences: List[UseStatement]
 	_contextReferences: List['Context']
 
 	def __init__(self):
@@ -1137,11 +1606,11 @@ class MixinDesignUnitWithContext:
 		self._contextReferences = []
 
 	@property
-	def LibraryReferences(self) -> List[Library]:
+	def LibraryReferences(self) -> List[LibraryStatement]:
 		return self._libraryReferences
 
 	@property
-	def PackageReferences(self) -> List[PackageReference]:
+	def PackageReferences(self) -> List[UseStatement]:
 		return self._packageReferences
 
 	@property
@@ -1165,8 +1634,8 @@ class SecondaryUnit(DesignUnit):
 
 @export
 class Context(PrimaryUnit):
-	_libraryReferences: List[LibraryReference]
-	_packageReferences: List[PackageReference]
+	_libraryReferences: List[LibraryStatement]
+	_packageReferences: List[UseStatement]
 
 	def __init__(self, name):
 		super().__init__(name)
@@ -1175,11 +1644,11 @@ class Context(PrimaryUnit):
 		self._packageReferences = []
 
 	@property
-	def LibraryReferences(self) -> List[LibraryReference]:
+	def LibraryReferences(self) -> List[LibraryStatement]:
 		return self._libraryReferences
 
 	@property
-	def PackageReferences(self) -> List[PackageReference]:
+	def PackageReferences(self) -> List[UseStatement]:
 		return self._packageReferences
 
 
